@@ -108,10 +108,6 @@ html_document_base <- function(smart = TRUE,
 
     preserved_chunks <<- extract_preserve_chunks(input_file)
 
-    # Avoid pagetitle warning from pandoc2.0 when title is missing
-    if (pandoc2.0() && is.null(metadata$title) && is.null(metadata$pagetitle))
-      args <- c(args, "--metadata", paste0("pagetitle=", input_file))
-
     # a lua filters added if pandoc2.0
     args <- c(args, pandoc_lua_filters(c("pagebreak.lua", "latex-div.lua")))
 
