@@ -5,16 +5,12 @@
 #' assumes you will include the output into an existing document (e.g. a blog
 #' post).
 #'
+#' See the \href{https://rmarkdown.rstudio.com/html_document_format.html}{online
+#' documentation} for additional details on using the \code{html_fragment}
+#' format.
 #' @param mathjax \code{TRUE} to convert $ and $$ math blocks into MathJax
 #'   compatible output. Note that you'll still need to ensure that the page
 #'   where the fragment is included loads the required MathJax scripts.
-#'
-#' @details
-#'
-#' See the \href{http://rmarkdown.rstudio.com/html_document_format.html}{online
-#' documentation} for additional details on using the \code{html_fragment}
-#' format.
-#'
 #' @inheritParams html_document
 #' @param ... Additional arguments passed to \code{\link{html_document}}
 #' @return R Markdown output format to pass to \code{\link{render}}
@@ -44,6 +40,6 @@ html_fragment <- function(number_sections = FALSE,
     dev = dev, df_print = df_print, smart = smart, keep_md = keep_md,
     md_extensions = md_extensions, pandoc_args = pandoc_args, includes = includes,
     mathjax = NULL, section_divs = section_divs, highlight = NULL, theme = NULL, ...,
-    template = rmarkdown_system_file("rmd/fragment/default.html")
+    template = pkg_file("rmd/fragment/default.html")
   )
 }
