@@ -1,12 +1,16 @@
-
 #' Convert to a slidy presentation
 #'
 #' Format for converting from R Markdown to a slidy presentation.
 #'
+#' See the \href{https://rmarkdown.rstudio.com/slidy_presentation_format.html}{online
+#' documentation} for additional details on using the \code{slidy_presentation}
+#' format.
+#'
+#' For more information on markdown syntax for presentations see the
+#' \href{https://pandoc.org/README.html}{pandoc online documentation}.
 #' @inheritParams pdf_document
 #' @inheritParams html_document
 #' @inheritParams beamer_presentation
-#'
 #' @param duration Duration (in minutes) of the slide deck. This value is used
 #'   to add a countdown timer to the slide footer.
 #' @param footer Footer text (e.g. organization name and/or copyright)
@@ -15,22 +19,9 @@
 #'   using the 'S' (smaller) and 'B' (bigger) keys.
 #' @param ... Additional function arguments to pass to the base R Markdown HTML
 #'   output formatter \code{\link{html_document_base}}
-#'
 #' @return R Markdown output format to pass to \code{\link{render}}
-#'
-#' @details
-#'
-#' See the
-#' \href{http://rmarkdown.rstudio.com/slidy_presentation_format.html}{online
-#' documentation} for additional details on using the \code{slidy_presentation}
-#' format.
-#'
-#' For more information on markdown syntax for presentations see the
-#' \href{http://pandoc.org/README.html}{pandoc online documentation}.
-#'
 #' @examples
 #' \dontrun{
-#'
 #' library(rmarkdown)
 #'
 #' # simple invocation
@@ -39,7 +30,6 @@
 #' # specify an option for incremental rendering
 #' render("pres.Rmd", slidy_presentation(incremental = TRUE))
 #' }
-#'
 #' @export
 slidy_presentation <- function(incremental = FALSE,
                                duration = NULL,
@@ -70,10 +60,8 @@ slidy_presentation <- function(incremental = FALSE,
 
   # template path and assets
   if (identical(template, "default"))
-    args <- c(args, "--template",
-              pandoc_path_arg(rmarkdown_system_file(
-                "rmd/slidy/default.html")))
-  else if (!is.null(template))
+    template <- pkg_file("rmd/slidy/default.html")
+  if (!is.null(template))
     args <- c(args, "--template", pandoc_path_arg(template))
 
   # html dependency for slidy
@@ -150,14 +138,12 @@ slidy_presentation <- function(incremental = FALSE,
                                      ...))
 }
 
-
 html_dependency_slidy <- function() {
   htmlDependency(
     name = "slidy",
     version = "2",
-    src = rmarkdown_system_file("rmd/slidy/Slidy2"),
+    src = pkg_file("rmd/slidy/Slidy2"),
     script = "scripts/slidy.js",
     stylesheet = "styles/slidy.css"
   )
 }
-
